@@ -19,6 +19,7 @@ class utility:
         region_name=region_name
         )
         print("Boto3 Session Started")
+        region = region_name
         return session
 
     def list_users(self,day):
@@ -56,7 +57,7 @@ class utility:
             
 
         df = pd.DataFrame(result)
-        df.to_csv ('_iam_userlist.csv', index = None)
+        df.to_csv ('iam_userlist.csv', index = None)
 
     def ebs_volume_report(self):
 
@@ -70,21 +71,9 @@ class utility:
             writer = csv.writer(csvfile)
             writer.writerow(header)
             for page in response_iterator:
-                cnt = 1
                 for  volume in page['Volumes']:
-
-                    print(cnt)
                     for att in volume['Attachments']:
-                        print('Instance ID =', att['InstanceId'])
                         inst = att['InstanceId']
-                        print('Volume ID = ', volume['VolumeId']) 
-                        print('Volume Size =' , volume['Size'],"GB")
-                        print("AvailabilityZone = ", volume['AvailabilityZone'])
-                        print("Volume Type = ", volume['VolumeType'])
-                        print("Volume Status =", volume['State'])
-                            #print("IOPS =", volume['Iops'])
-                        print("--------")
-                        cnt = cnt + 1
                         data = [inst,volume['VolumeId'],volume['Size'],volume['AvailabilityZone'],volume['VolumeType'],volume['State'],volume['Iops']]
 
             writer.writerow(data)
@@ -116,3 +105,25 @@ class utility:
                         print("User: ", user.user_name  , "Key: ",  AccessId , "Keys is InActive")
             else:
                 print ("User: ", user.user_name  , "No KEYS for this USER")     #".. proof: " , Metadata
+    def NatGatway(self):
+
+        client = session.client('ec2')
+        response = client.describe_nat_gateways()
+
+        header = ['NatGatewayId','State', 'Allocation_Id', 'Network_Interface_Id','Private_IP','Public_IP']
+        with open('NatGatewaydata.csv','w', newline = '') as csvfile:
+            writer = csv.writer(csvfile)
+            writer.writerow(header)
+
+            gateways = response['NatGateways']
+            for i in gateways:
+                gatewayAddressess = i['NatGatewayAddresses']
+                state = i['State']
+                Allocation_id = gatewayAddressess[0]['AllocationId']
+                NetworkInterfaceId = gatewayAddressess[0]['NetworkInterfaceId']
+                Private_Ip = gatewayAddressess[0]['PrivateIp']
+                Public_Ip = gatewayAddressess[0]['PublicIp']
+                natgatewayid = i['NatGatewayId']
+                data=[natgatewayid['NatGatewayId'],state['State'],Allocation_id['Allocation_Id'],NetworkInterfaceId['Network_Interface_Id'],Private_Ip['Private_IP'],Public_Ip['Public_IP']]
+                writer.writerow(data)
+
